package com.ynet.life.sujrb.file.parser;

import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.format.LifeFormat;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.FileConstants;
import com.ynet.life.sujrb.file.MultiTransferSummary;
import java.io.FileInputStream;
import java.io.IOException;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/MultiTransExcelFileParser.class */
public class MultiTransExcelFileParser implements BatchFileParserInterface {
    private String formatter;

    public void setFormatter(String formatter) {
        this.formatter = formatter;
    }

    public MultiTransExcelFileParser() {
    }

    public MultiTransExcelFileParser(String formatter) {
        this.formatter = formatter;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        int max;
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            MultiTransferSummary result = new MultiTransferSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                HSSFRow summaryRow = sheet.getRow(0);
                BigDecimal totalAmountInput = new BigDecimal(getCellContent(summaryRow, 1, false));
                int recordNumberInput = new Double(getCellContent(summaryRow, 3, true)).intValue();
                int rowIndex = 2;
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (recordRow == null) {
                        break;
                    }
                    result.addRecord(getRecordMap(recordRow, this.formatter));
                }
                if (result.getRecordNumber() != recordNumberInput || totalAmountInput.compareTo(result.getTotalAmount()) != 0) {
                    Trace.logWarning("LifeFile", "提交文件中总笔数或总金额和明细不符");
                    throw FileConstants.EXCEPTION_VALIDATE_FAIL;
                }
                try {
                    max = Integer.parseInt(LifeStandard.getSystemParam("CB_BATCH_TRANSFER_MAX_NUM"));
                } catch (NumberFormatException unused) {
                    max = 500;
                }
                if (recordNumberInput > max) {
                    Trace.logWarning("LifeAction", "EBCB0505::提交文件总笔数超过要求的值");
                    throw new TranFailException("EBCB0505", "提交文件总笔数超过要求的值", false);
                }
                return result;
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw FileConstants.EXCEPTION_PARSE_FAIL;
            }
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("EBLN0000", "文件读取失败", ex2);
        }
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String payAccount = getCellContent(recordRow, 0, true);
        String payAccountName = getCellContent(recordRow, 1, true);
        String recAccount = getCellContent(recordRow, 2, true);
        String recAccountName = getCellContent(recordRow, 3, true);
        String recAccountOpenBank = getCellContent(recordRow, 4, true);
        String unionBankNo = getCellContent(recordRow, 5, true);
        String recBankType = getCellContent(recordRow, 6, true);
        String currencyType = getCellContent(recordRow, 7, true);
        String payAmount = getCellContent(recordRow, 8, false);
        String rmtType = getCellContent(recordRow, 9, true);
        String transferTowardType = getCellContent(recordRow, 10, true);
        String tranChannel = getCellContent(recordRow, 11, true);
        String payUse = getCellContent(recordRow, 12, true);
        String payRem = getCellContent(recordRow, 13, true);
        result.put("payAccount", payAccount);
        result.put("payAccountName", payAccountName);
        result.put("recAccount", recAccount);
        result.put("recAccountName", recAccountName);
        result.put("recAccountOpenBank", recAccountOpenBank);
        result.put("unionBankNo", unionBankNo);
        result.put("recBankType", recBankType);
        result.put("currencyType", currencyType);
        result.put("payAmount", LifeFormat.unFormatCurrency(LifeFormat.formatCurrency(LifeFormat.unFormatCurrency(payAmount))));
        result.put("rmtType", rmtType);
        result.put("transferTowardType", transferTowardType);
        result.put("tranChannel", tranChannel);
        result.put("payUse", payUse);
        result.put("payRem", payRem);
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            switch (cell.getCellType()) {
                case 0:
                    String format = "######.##";
                    if (toInt) {
                        format = "#######";
                    }
                    result = new DecimalFormat(format).format(cell.getNumericCellValue());
                    break;
                case 1:
                    result = cell.getRichStringCellValue().getString();
                    break;
            }
            return result;
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
